"use client";

import React from 'react';
import {Header} from "@/components/header";
import {Contest, GetContestResponseTasksInner} from "../../../proto/tester/v1/api";
import {
    ActionIcon,
    Anchor,
    Button,
    Center,
    Group,
    Stack,
    Table,
    TableTbody,
    TableTd,
    TableTh,
    TableThead,
    TableTr,
    Title
} from "@mantine/core";
import Link from "next/link";
import {IconMail, IconTrash} from "@tabler/icons-react";
import {DeleteTask} from "@/shared/api";
import {useMutation} from "@tanstack/react-query";
import {useRouter} from "next/navigation";

type PageProps = {
    contest: Contest,
    tasks: Array<GetContestResponseTasksInner>
}

const Page = (props: PageProps) => {
    const router = useRouter();

    const mutation = useMutation({
        mutationFn: DeleteTask,
        onSuccess: async () => {
            await router.refresh();
        },
        retry: false
    });

    const rows = props.tasks.map((task) => (
        <TableTr key={task.task.id}>
            <TableTd>
                <Anchor component={Link}
                        href={`/contests/${props.contest.id}/tasks/${task.task.id}`}
                        c="var(--mantine-link-color)"
                        underline="always"
                >
                    {`${task.task.position + 1}. ${task.task.title}`}
                </Anchor>
            </TableTd>
            <TableTd>{task.best_solution.total_score}</TableTd>
            <TableTd>
                <Button component={Link} href={`/`} size="xs">
                    Мои посылки
                </Button>
            </TableTd>
            <TableTd>
                <ActionIcon onClick={() => mutation.mutate(task.task.id)}>
                    <IconTrash/>
                </ActionIcon>
            </TableTd>
        </TableTr>
    ))

    return (
        <Stack gap="xl">
            <header>
                <Header/>
            </header>
            <main>
                <Stack gap="xl" align="center">
                    <Title order={1}>{props.contest.title}</Title>
                    <Table horizontalSpacing="xl" align="center" w="fit-content">
                        <TableThead>
                            <TableTr>
                                <TableTh>Название</TableTh>
                                <TableTh>Баллы</TableTh>
                                <TableTh>
                                    <Center>
                                        <IconMail/>
                                    </Center>
                                </TableTh>
                                <TableTh>
                                    <Center>
                                        <IconTrash/>
                                    </Center>
                                </TableTh>
                            </TableTr>
                        </TableThead>
                        <TableTbody>{rows}</TableTbody>
                    </Table>
                    <Stack>
                        <Center>
                            <Group>
                                <Button size="md">
                                    Все посылки
                                </Button>
                                <Button size="md">
                                    Редактировать контест
                                </Button>
                            </Group>
                        </Center>
                        <Center>
                            <Group>
                                <Button size="md">
                                    Добавить пользователя
                                </Button>
                                <Button size="md">
                                    Добавить задачу
                                </Button>
                            </Group>
                        </Center>
                    </Stack>
                </Stack>
            </main>
        </Stack>
    );
};

export {Page as ClientPage};
