"use client";

import {
    ActionIcon,
    AppShell,
    AppShellAside,
    AppShellHeader,
    AppShellMain,
    Button,
    Pagination,
    Stack,
    Table,
    TableTbody,
    TableTd,
    TableTh,
    TableThead,
    TableTr,
    TextInput,
    Title
} from "@mantine/core";
import Link from "next/link";
import {IconPencil} from "@tabler/icons-react";
import {Header} from "@/components/header";
import React from "react";
import {User} from "../../../proto/user/v1/api";


type Props = {
    users: User[],
    page: number
    max_page: number
};

const roles = [
    "Студент",
    "Преподаватель",
    "Администратор",
];


const ClientPage = (props: Props) => {
    const rows = props.users.map((user) => (
        <TableTr key={user.id}>
            <TableTd>{user.username}</TableTd>
            {/*<TableTd>{user.email}</TableTd>*/}
            <TableTd>{roles[user.role]}</TableTd>
            <TableTd>{<ActionIcon size="xs" component={Link} href={`/users/${user.id}`}>
                <IconPencil/>
            </ActionIcon>}
            </TableTd>
        </TableTr>
    ));

    return (
        <AppShell header={{height: 70}}>
            <AppShellHeader>
                <Header/>
            </AppShellHeader>
            <AppShellMain px="16">
                <Stack align="center" w="fit-content" m="auto" pt="16" gap="16">
                    <Title>Пользователи</Title>
                    <Table horizontalSpacing="xl">
                        <TableThead>
                            <TableTr>
                                <TableTh>Никнейм</TableTh>
                                {/*<TableTh>Почта</TableTh>*/}
                                <TableTh>Роль</TableTh>
                                <TableTh></TableTh>
                            </TableTr>
                        </TableThead>
                        <TableTbody>{rows}</TableTbody>
                    </Table>
                    <Pagination total={props.max_page}
                                value={props.page}
                                getItemProps={(page) => ({
                                    component: Link,
                                    href: `/users?page=${page}`,
                                })}
                                getControlProps={(control) => {
                                    if (control === 'next') {
                                        if (props.page === props.max_page) {
                                            return {component: Link, href: `/users?page=${props.page}`};
                                        }

                                        return {component: Link, href: `/users?page=${+props.page + 1}`};
                                    }

                                    if (control === 'previous') {
                                        if (props.page === 1) {
                                            return {component: Link, href: `/users?page=${props.page}`};
                                        }
                                        return {component: Link, href: `/users?page=${+props.page - 1}`};
                                    }

                                    return {};
                                }}
                    />
                </Stack>
            </AppShellMain>
            <AppShellAside withBorder={false} px="16">
                <Stack pt="16">
                    <TextInput placeholder="Поиск"/>
                    <Button component={Link} href="/users/new">
                        Добавить пользователя
                    </Button>
                </Stack>
            </AppShellAside>
        </AppShell>
    );
};

export {ClientPage};